@@ -70,9 +70,10 @@ class Plugin(GlancesPlugin):
     stats is a list
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args,
+                                     config=config,
                                      items_history_list=items_history_list,
                                      stats_init_value=[])
 
@@ -98,7 +99,7 @@ class Plugin(GlancesPlugin):
             # and ignore all others (e.g. memory partitions such as /dev/shm)
             try:
                 fs_stat = psutil.disk_partitions(all=False)
-            except UnicodeDecodeError:
+            except (UnicodeDecodeError, PermissionError):
                 return self.stats
 
             # Optionnal hack to allow logicals mounts points (issue #448)
@@ -113,7 +114,8 @@ class Plugin(GlancesPlugin):
             # Loop over fs
             for fs in fs_stat:
                 # Do not take hidden file system into account
-                if self.is_hide(fs.mountpoint):
+                # Also check device name (see issue #1606)
+                if self.is_hide(fs.mountpoint) or self.is_hide(fs.device):
                     continue
                 # Grab the disk usage
                 try:
@@ -162,7 +164,11 @@ class Plugin(GlancesPlugin):
                         'used': used,
                         'percent': percent,
                         'key': self.get_key()}
-                    stats.append(fs_current)
+                    # Do not take hidden file system into account
+                    if self.is_hide(fs_current['mnt_point']):
+                        continue
+                    else:
+                        stats.append(fs_current)
             else:
                 # Default behavior
                 for fs in fs_stat:
@@ -173,7 +179,11 @@ class Plugin(GlancesPlugin):
                         'used': int(fs_stat[fs]['used']) * 1024,
                         'percent': float(fs_stat[fs]['percent']),
                         'key': self.get_key()}
-                    stats.append(fs_current)
+                    # Do not take hidden file system into account
+                    if self.is_hide(fs_current['mnt_point']) or self.is_hide(fs_current['device_name']):
+                        continue
+                    else:
+                        stats.append(fs_current)
 
         # Update the stats
         self.stats = stats
