@@ -53,15 +53,15 @@ class Plugin(GlancesPlugin):
     stats is a dict
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args)
+        super(Plugin, self).__init__(args=args, config=config)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
 
         # Get the public IP address once (not for each refresh)
-        if not self.is_disable():
+        if not self.is_disable() and not import_error_tag:
             self.public_address = PublicIpAddress().get()
 
     @GlancesPlugin._check_decorator
@@ -114,7 +114,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disable() or import_error_tag:
             return ret
 
         # Build the string message
@@ -175,6 +175,9 @@ class PublicIpAddress(object):
             if q.qsize() > 0:
                 ip = q.get()
 
+        if ip is None:
+            return None
+
         return ', '.join(set([x.strip() for x in ip.split(',')]))
 
     def _get_ip_public(self, queue_target, url, json=False, key=None):
