@@ -34,6 +34,7 @@ from glances.history import GlancesHistory
 from glances.logger import logger
 from glances.events import glances_events
 from glances.thresholds import glances_thresholds
+from glances.timer import Counter
 
 
 class GlancesPlugin(object):
@@ -87,9 +88,10 @@ class GlancesPlugin(object):
 
         # Init the limits (configuration keys) dictionnary
         self._limits = dict()
-        if not self.load_limits(config=config):
-            logger.debug('Can not load section {} in {}'.format(self.plugin_name,
-                                                                config))
+        if config is not None:
+            logger.debug('Load section {} in {}'.format(self.plugin_name,
+                                                        config.config_file_paths()))
+            self.load_limits(config=config)
 
         # Init the actions
         self.actions = GlancesActions(args=args)
@@ -500,6 +502,7 @@ class GlancesPlugin(object):
             return False
 
         # Read the global section
+        # @TODO: not optimized because this section is loaded for each plugin...
         if config.has_section('global'):
             self._limits['history_size'] = config.get_float_value('global', 'history_size', default=28800)
             logger.debug("Load configuration key: {} = {}".format('history_size', self._limits['history_size']))
@@ -926,11 +929,14 @@ class GlancesPlugin(object):
     def _log_result_decorator(fct):
         """Log (DEBUG) the result of the function fct."""
         def wrapper(*args, **kw):
+            counter = Counter()
             ret = fct(*args, **kw)
-            logger.debug("%s %s %s return %s" % (
+            duration = counter.get()
+            logger.debug("%s %s %s return %s in %s seconds" % (
                 args[0].__class__.__name__,
                 args[0].__class__.__module__[len('glances_'):],
-                fct.__name__, ret))
+                fct.__name__, ret,
+                duration))
             return ret
         return wrapper
 
