@@ -59,9 +59,10 @@ class Plugin(GlancesPlugin):
     'stats' is a dictionary.
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the quicklook plugin."""
         super(Plugin, self).__init__(args=args,
+                                     config=config,
                                      items_history_list=items_history_list)
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -129,7 +130,9 @@ class Plugin(GlancesPlugin):
             sparkline_tag = data.available
         if not sparkline_tag:
             # Fallback to bar if Sparkline module is not installed
-            data = Bar(max_width)
+            data = Bar(max_width,
+                       percentage_char=self.get_conf_value('percentage_char',
+                                                           default=['|'])[0])
 
         # Build the string message
         if 'cpu_name' in self.stats and 'cpu_hz_current' in self.stats and 'cpu_hz' in self.stats:
